@@ -617,6 +617,11 @@ class SQLAlchemyDatabase:
         cursor = raw_conn.cursor()
 
         try:
+            # Connection tuning for bulk operations
+            cursor.execute("SET synchronous_commit = OFF")
+            cursor.execute("SET wal_buffers = '16MB'")
+            cursor.execute("SET checkpoint_completion_target = 0.9")
+
             # Precompute ON CONFLICT clause based on mode
             conflict_cols = ", ".join(f'"{c}"' for c in pks)
             if mode == "RAISE":
@@ -631,30 +636,29 @@ class SQLAlchemyDatabase:
                 else:
                     on_conflict = f"ON CONFLICT ({conflict_cols}) DO NOTHING"
 
+            # Create single temp table outside loop
+            temp_table = f"temp_{table}_copy"
+            non_id_cols = [c for c in cols if c.upper() != "ID"]
+            non_id_col_list = ", ".join(f'"{c}"' for c in non_id_cols)
+
+            cursor.execute(f'CREATE TEMP TABLE "{temp_table}" AS SELECT {non_id_col_list} FROM "{table}" WHERE FALSE')
+
             # Process each batch
             for batch_idx, offset in enumerate(range(0, data.height, chunk_size)):
                 batch = data.slice(offset, chunk_size)
                 if batch.height == 0:
                     continue
 
-                temp_table = f"temp_{table}_{batch_idx}"
+                # 1) Clear temp table (much faster than CREATE/DROP)
+                cursor.execute(f'TRUNCATE "{temp_table}"')
 
-                # 1) Create temp table (just structure, no constraints/indexes, exclude auto-generated ID)
-                # Get non-ID columns for temp table
-                non_id_cols = [c for c in cols if c.upper() != "ID"]
-                non_id_col_list = ", ".join(f'"{c}"' for c in non_id_cols)
-
-                cursor.execute(
-                    f'CREATE TEMP TABLE "{temp_table}" AS SELECT {non_id_col_list} FROM "{table}" WHERE FALSE'
-                )
-
-                # 2) COPY data into staging (input data shouldn't have ID column)
+                # 2) COPY data into staging
                 buf = io.StringIO()
                 batch.write_csv(buf)
                 buf.seek(0)
                 cursor.copy_expert(f'COPY "{temp_table}" ({non_id_col_list}) FROM STDIN WITH CSV HEADER', buf)
 
-                # 3) INSERT FROM staging into real table (only non-ID columns)
+                # 3) INSERT FROM staging into real table
                 insert_sql = (
                     f'INSERT INTO "{table}" ({non_id_col_list}) SELECT {non_id_col_list} FROM "{temp_table}" '
                     + on_conflict
@@ -672,9 +676,6 @@ class SQLAlchemyDatabase:
                     df_ids = pl.read_csv(buf_out)
                     all_id_maps.append(df_ids)
 
-                # Drop temp table explicitly
-                cursor.execute(f'DROP TABLE IF EXISTS "{temp_table}"')
-
                 # Update progress bar with number of rows processed
                 if show_progress:
                     progress_bar.update(batch.height)
