@@ -232,7 +232,7 @@ class DataLoader:
         if all_categories:
             return pl.concat(all_categories)
 
-        return pl.DataFrame(schema={"name": pl.Utf8, "companyID": pl.Int64, "id": pl.Int64})
+        return pl.DataFrame(schema={"name": pl.Utf8, "companyID": pl.Int64, "ID": pl.Int64})
 
     def _extract_category_relations(self, categories_dict: dict) -> pl.DataFrame:
         """Extract parent-child relationships from categories dictionary."""
@@ -333,12 +333,12 @@ class DataLoader:
         # Create product-category mapping using polars-native operations
         products = (
             products.join(
-                product_ids.rename({"name": "product", "id": "productID"}),
+                product_ids.rename({"name": "product", "ID": "productID"}),
                 on="product",
                 how="left",
             )
             .join(
-                category_ids.select(["name", "id"]).rename({"name": "category", "id": "categoryID"}),
+                category_ids.select(["name", "ID"]).rename({"name": "category", "ID": "categoryID"}),
                 on="category",
                 how="left",
             )
@@ -374,9 +374,9 @@ class DataLoader:
         time_sku_data = (
             time_sku_data.select(["store", "product"])
             .unique()
-            .join(store_ids.drop("companyID").rename({"name": "store", "id": "storeID"}), on="store", how="left")
+            .join(store_ids.drop("companyID").rename({"name": "store", "ID": "storeID"}), on="store", how="left")
             .join(
-                product_ids.drop("companyID").rename({"name": "product", "id": "productID"}), on="product", how="left"
+                product_ids.drop("companyID").rename({"name": "product", "ID": "productID"}), on="product", how="left"
             )
         )
 
@@ -390,7 +390,7 @@ class DataLoader:
             returning_id=True,
         )
 
-        time_sku_data = time_sku_data.join(result.rename({"id": "skuID"}), on=["storeID", "productID"], how="left")
+        time_sku_data = time_sku_data.join(result.rename({"ID": "skuID"}), on=["storeID", "productID"], how="left")
 
         logger.info("Writing SKUs to db complete, got %d sku IDs back", len(result))
 
@@ -415,7 +415,9 @@ class DataLoader:
 
         # Merge time_sku_data with sku_ids on product, store
         time_sku_data = (
-            time_sku_data.join(sku_ids, on=["product", "store"], how="left")
+            time_sku_data.select(["product", "store", "date"])
+            .unique()
+            .join(sku_ids, on=["product", "store"], how="left")
             .join(dates_df, on="date", how="left")
             .select(["skuID", "dateID"])
         )
@@ -431,7 +433,7 @@ class DataLoader:
         logger.info("Writing datapoints to db complete, got %d datapoint IDs back", len(result))
 
         result = (
-            result.rename({"id": "datapointID"})
+            result.rename({"ID": "datapointID"})
             .join(sku_ids, on=["skuID"], how="left")
             .join(dates_df, on=["dateID"], how="left")
         )
@@ -482,7 +484,7 @@ class DataLoader:
         # )
 
         # # Add featureID to feature description map
-        # feature_desc = feature_desc.with_columns(featureID=pl.Series(feature_description_result["id"]))
+        # feature_desc = feature_desc.with_columns(featureID=pl.Series(feature_description_result["ID"]))
         # feature_desc = feature_desc.rename({"name": "feature"})
 
         # # Prepare feature map for writing
